package org.energy.core.interceptor;

import com.dayu.daf.core.secure.DafUser;
import com.dayu.daf.core.secure.utils.SecureUtil;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.api.ResultCode;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.dayu.daf.core.tool.jackson.JsonUtil;
import com.dayu.daf.core.tool.utils.RedisUtil;
import com.dayu.daf.core.tool.utils.WebUtil;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.energy.common.cache.CacheNames;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.AsyncHandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Objects;

@Slf4j
@AllArgsConstructor
@Component
public class EnergySecureInterceptor implements AsyncHandlerInterceptor {

	private RedisUtil redisUtil;

	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
		DafUser dafUser = SecureUtil.getUser();
		Object userId = null;
		if (dafUser != null) {
			userId = redisUtil.get(CacheNames.DEL_USER_ID + dafUser.getUserId());
		}
		if (null != dafUser && userId == null) {
			return true;
		} else {
			log.warn("签名认证失败，请求接口：{}，请求IP：{}，请求参数：{}", request.getRequestURI(), WebUtil.getIP(request), JsonUtil.toJson(request.getParameterMap()));
			R result = R.fail(ResultCode.UN_AUTHORIZED);
			response.setCharacterEncoding(DafConstant.UTF_8);
			response.setHeader(DafConstant.CONTENT_TYPE_NAME, MediaType.APPLICATION_JSON_VALUE);
			response.setStatus(HttpServletResponse.SC_OK);
			try {
				response.getWriter().write(Objects.requireNonNull(JsonUtil.toJson(result)));
			} catch (IOException ex) {
				log.error(ex.getMessage());
			}
			return false;
		}
	}
}
