/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.energy.core.log.config;

import com.dayu.daf.core.launch.props.DafProperties;
import com.dayu.daf.core.launch.server.ServerInfo;
import com.dayu.daf.core.log.aspect.ApiLogAspect;
import com.dayu.daf.core.log.logger.DafLogger;
import lombok.AllArgsConstructor;
import org.energy.core.log.event.ApiLogListener;
import org.energy.core.log.event.ErrorLogListener;
import org.energy.core.log.event.UsualLogListener;
import org.energy.modules.system.service.ILogService;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 日志工具自动配置
 *
 * @author Chill
 */
@Configuration(proxyBeanMethods = false)
@AllArgsConstructor
@ConditionalOnWebApplication
//@AutoConfigureBefore(LogUsualMapper.class)
public class DafLogToolAutoConfiguration {

	private final ILogService logService;
	private final ServerInfo serverInfo;
	private final DafProperties dafProperties;

	@Bean(value = "energyApiLogAspect")
	public ApiLogAspect apiLogAspect() {
		return new ApiLogAspect();
	}

	@Bean(value = "energyDafLogger")
	public DafLogger dafLogger() {
		return new DafLogger();
	}

	@Bean(value = "energyApiLogListener")
	public ApiLogListener apiLogListener() {
		return new ApiLogListener(logService, serverInfo, dafProperties);
	}

	@Bean(value = "energyErrorEventListener")
	public ErrorLogListener errorEventListener() {
		return new ErrorLogListener(logService, serverInfo, dafProperties);
	}

	@Bean(value = "energyDafEventListener")
	public UsualLogListener dafEventListener() {
		return new UsualLogListener(logService, serverInfo, dafProperties);
	}

}
