/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.inspection.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.inspection.entity.InspectionRoute;
import org.energy.modules.inspection.excel.InspectionObjectExcel;
import org.energy.modules.inspection.excel.InspectionRouteExcel;
import org.energy.modules.leger.excel.EquipmentLedgerExcel;
import org.energy.modules.leger.vo.EquipmentLedgerVO;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.inspection.entity.InspectionObject;
import org.energy.modules.inspection.vo.InspectionObjectVO;
import org.energy.modules.inspection.service.IInspectionObjectService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 巡检对象一览 控制器
 *
 * @author Daf
 * @since 2024-07-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("/inspection/inspectionobject")
@Api(value = "巡检对象一览", tags = "巡检对象一览接口")
public class InspectionObjectController extends DafController {

	private IInspectionObjectService inspectionObjectService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inspectionObject")
	public R<InspectionObject> detail(InspectionObject inspectionObject) {
		InspectionObject detail = inspectionObjectService.getOne(Condition.getQueryWrapper(inspectionObject));
		return R.data(detail);
	}

	/**
	 * 分页 巡检对象一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inspectionObject")
	public R<IPage<InspectionObject>> list(InspectionObject inspectionObject, Query query) {
		QueryWrapper<InspectionObject> qw = new QueryWrapper<>();
		qw.orderByAsc("object_No");
		if (StringUtil.isNotEmpty(inspectionObject.getObjectNo())) {
			qw.lambda().like(InspectionObject::getObjectNo, inspectionObject.getObjectNo());
		}
		if (StringUtil.isNotEmpty(inspectionObject.getObjectName())) {
			qw.lambda().like(InspectionObject::getObjectName, inspectionObject.getObjectName());
		}
		if (null != inspectionObject.getStation()) {
			qw.lambda().eq(InspectionObject::getStation, inspectionObject.getStation());
		}
		if (null != inspectionObject.getIstatus()) {
			qw.lambda().eq(InspectionObject::getIstatus, inspectionObject.getIstatus());
		}
		if (StringUtil.isNotEmpty(inspectionObject.getObjectArea())){
			qw.lambda().like(InspectionObject::getObjectArea, inspectionObject.getObjectArea());
		}
		IPage<InspectionObject> pages = inspectionObjectService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 巡检对象一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inspectionObject")
	public R<IPage<InspectionObjectVO>> page(InspectionObjectVO inspectionObject, Query query) {
		IPage<InspectionObjectVO> pages = inspectionObjectService.selectInspectionObjectPage(Condition.getPage(query), inspectionObject);
		return R.data(pages);
	}

	/**
	 * 新增 巡检对象一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inspectionObject")
	public R save(@Valid @RequestBody InspectionObject inspectionObject) {
		return R.status(inspectionObjectService.save(inspectionObject));
	}

	/**
	 * 修改 巡检对象一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inspectionObject")
	public R update(@Valid @RequestBody InspectionObject inspectionObject) {
		return R.status(inspectionObjectService.updateById(inspectionObject));
	}

	/**
	 * 新增或修改 巡检对象一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inspectionObject")
	public R submit(@Valid @RequestBody InspectionObject inspectionObject) {
		inspectionObject.setIstatus(1);
		String date = LocalDate.now().toString().replace("-","");
		String maxNo = inspectionObjectService.getMaxNo("'%" + date + "%'");
		int number;
		if (StringUtil.isNotEmpty(maxNo)){
			number = Integer.parseInt(maxNo.substring(9));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%04d", number);
		String no = "D" + date + numFormat;
		inspectionObject.setObjectNo(no);
		return R.status(inspectionObjectService.saveOrUpdate(inspectionObject));
	}


	/**
	 * 删除 巡检对象一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inspectionObjectService.deleteLogic(Func.toLongList(ids)));
	}
	/**
	 * 生效
	 */
	@PostMapping("/takeEffect")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "生效", notes = "传入ids")
	public R takeEffect(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.updateInspectionObject(1, "", ids);
	}

	/**
	 * 失效
	 */
	@PostMapping("/lapse")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "失效", notes = "传入ids")
	public R lapse(@ApiParam(value = "主键集合", required = true) @RequestParam String ids,@ApiParam(value = "取消原因", required = true) @RequestParam String reason) {
		return this.updateInspectionObject(0, reason, ids);
	}

	/**
	 * 生效OR失效
	 */
	public R updateInspectionObject(Integer status, String reason, String ids) {
		List<InspectionObject> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			InspectionObject inspectionObject = new InspectionObject();
			inspectionObject.setId(Long.parseLong(id));
			inspectionObject.setCancelReason(reason);
			inspectionObject.setIstatus(status);
			list.add(inspectionObject);
		}
		return R.status(inspectionObjectService.updateBatchById(list));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportInspectionObject(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		InspectionObjectVO vo = DataUtils.mapToEntity(entity, InspectionObjectVO::new);
		List<InspectionObjectExcel> list = inspectionObjectService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("巡检对象数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), InspectionObjectExcel.class).sheet("巡检对象").doWrite(list);
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getObjectList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "获取对象编号", notes = "获取对象编号")
	public R<List<InspectionObject>> getObjectNoList() {
		List<InspectionObject> routeList = inspectionObjectService.getObjectList();
		return R.data(routeList);
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getDetailList")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取对象信息", notes = "获取对象信息")
	public R<InspectionObject> getDetailList(String objectNo) {
		InspectionObject DetailList = inspectionObjectService.getDetailList("'" + objectNo + "'");
		return R.data(DetailList);
	}
}
