/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.inspection.controller;

import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.inspection.entity.InspectionTasks;
import org.energy.modules.leger.entity.InventoryDocument;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.inspection.entity.InspectionResult;
import org.energy.modules.inspection.vo.InspectionResultVO;
import org.energy.modules.inspection.service.IInspectionResultService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 巡检结果 控制器
 *
 * @author Daf
 * @since 2024-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("/inspection/inspectionresult")
@Api(value = "巡检结果", tags = "巡检结果接口")
public class InspectionResultController extends DafController {

	private IInspectionResultService inspectionResultService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inspectionResult")
	public R<InspectionResult> detail(InspectionResult inspectionResult) {
		InspectionResult detail = inspectionResultService.getOne(Condition.getQueryWrapper(inspectionResult));
		return R.data(detail);
	}

	/**
	 * 分页 巡检结果
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inspectionResult")
	public R<IPage<InspectionResult>> list(InspectionResult inspectionResult, Query query) {
		IPage<InspectionResult> pages = inspectionResultService.page(Condition.getPage(query), Condition.getQueryWrapper(inspectionResult));
		return R.data(pages);
	}

	/**
	 * 自定义分页 巡检结果
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inspectionResult")
	public R<IPage<InspectionResultVO>> page(InspectionResultVO inspectionResult, Query query) {
		IPage<InspectionResultVO> pages = inspectionResultService.selectInspectionResultPage(Condition.getPage(query), inspectionResult);
		return R.data(pages);
	}

	/**
	 * 新增 巡检结果
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inspectionResult")
	public R save(@Valid @RequestBody InspectionResult inspectionResult) {
		return R.status(inspectionResultService.save(inspectionResult));
	}

	/**
	 * 修改 巡检结果
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inspectionResult")
	public R update(@Valid @RequestBody InspectionResult inspectionResult) {
		return R.status(inspectionResultService.updateById(inspectionResult));
	}

	/**
	 * 新增或修改 巡检结果
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inspectionResult")
	public R submit(@Valid @RequestBody InspectionResult inspectionResult) {
		String maxResultNo = inspectionResultService.getMaxResultNo("'%" + inspectionResult.getTaskNo() + "%'");
		int number;
		if (StringUtil.isNotEmpty(maxResultNo)){
			number = Integer.parseInt(maxResultNo.substring(13));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%04d", number);
		String resultNo = inspectionResult.getTaskNo() + numFormat;
		inspectionResult.setResultNo(resultNo);
		return R.status(inspectionResultService.saveOrUpdate(inspectionResult));
	}

	/**
	 * 删除 巡检结果
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inspectionResultService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 技术参数一览
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入inventoryDocument")
	public R<List<InspectionResult>> getList(InspectionResult inspectionResult) {
		List<InspectionResult> list = inspectionResultService.list(Condition.getQueryWrapper(inspectionResult));
		return R.data(list);
	}

}
