/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.inspection.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.inspection.entity.InspectionRoute;
import org.energy.modules.inspection.excel.InspectionRouteExcel;
import org.energy.modules.inspection.excel.InspectionTasksExcel;
import org.energy.modules.leger.entity.EquipmentLedger;
import org.energy.modules.leger.excel.EquipmentLedgerExcel;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.inspection.entity.InspectionTasks;
import org.energy.modules.inspection.vo.InspectionTasksVO;
import org.energy.modules.inspection.service.IInspectionTasksService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 巡检任务 控制器
 *
 * @author Daf
 * @since 2024-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("/inspection/inspectiontasks")
@Api(value = "巡检任务", tags = "巡检任务接口")
public class InspectionTasksController extends DafController {

	private IInspectionTasksService inspectionTasksService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inspectionTasks")
	public R<InspectionTasks> detail(InspectionTasks inspectionTasks) {
		InspectionTasks detail = inspectionTasksService.getOne(Condition.getQueryWrapper(inspectionTasks));
		return R.data(detail);
	}

	/**
	 * 分页 巡检任务
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inspectionTasks")
	public R<IPage<InspectionTasks>> list(InspectionTasks inspectionTasks, Query query) {
		QueryWrapper<InspectionTasks> qw = new QueryWrapper<>();
		qw.orderByAsc("task_no");
		// 场站
		if (null != inspectionTasks.getStation()) {
			qw.lambda().eq(InspectionTasks::getStation, inspectionTasks.getStation());
		}
		// 状态
		if (null != inspectionTasks.getTaskStatus()) {
			qw.lambda().eq(InspectionTasks::getTaskStatus, inspectionTasks.getTaskStatus());
		}
		// 任务编号
		if (StringUtil.isNotEmpty(inspectionTasks.getTaskNo())) {
			qw.lambda().like(InspectionTasks::getTaskNo, inspectionTasks.getTaskNo());
		}
		// 任务名称
		if (StringUtil.isNotEmpty(inspectionTasks.getTaskName())) {
			qw.lambda().like(InspectionTasks::getTaskName, inspectionTasks.getTaskName());
		}
		// 任务生成日期
		if (StringUtil.isNotEmpty(inspectionTasks.getTaskStartDate())) {
			qw.lambda().like(InspectionTasks::getTaskStartDate, inspectionTasks.getTaskStartDate());
		}
		// 任务完成日期
		if (StringUtil.isNotEmpty(inspectionTasks.getTaskEndDate())) {
			qw.lambda().like(InspectionTasks::getTaskEndDate, inspectionTasks.getTaskEndDate());
		}
		// 责任人
		if (StringUtil.isNotEmpty(inspectionTasks.getResponsiblePerson())) {
			qw.lambda().like(InspectionTasks::getResponsiblePerson, inspectionTasks.getResponsiblePerson());
		}
		IPage<InspectionTasks> pages = inspectionTasksService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 巡检任务
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inspectionTasks")
	public R<IPage<InspectionTasksVO>> page(InspectionTasksVO inspectionTasks, Query query) {
		IPage<InspectionTasksVO> pages = inspectionTasksService.selectInspectionTasksPage(Condition.getPage(query), inspectionTasks);
		return R.data(pages);
	}

	/**
	 * 新增 巡检任务
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inspectionTasks")
	public R save(@Valid @RequestBody InspectionTasks inspectionTasks) {
		return R.status(inspectionTasksService.save(inspectionTasks));
	}

	/**
	 * 修改 巡检任务
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inspectionTasks")
	public R update(@Valid @RequestBody InspectionTasks inspectionTasks) {
		return R.status(inspectionTasksService.updateById(inspectionTasks));
	}

	/**
	 * 新增或修改 巡检任务
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inspectionTasks")
	public R submit(@Valid @RequestBody InspectionTasks inspectionTasks) {
		inspectionTasks.setTaskStatus(1L);
		String date = LocalDate.now().toString().replace("-","");
		String maxTaskNo = inspectionTasksService.getMaxTaskNo(date);
		int number;
		if (StringUtil.isNotEmpty(maxTaskNo)){
			number = Integer.parseInt(maxTaskNo.substring(9));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%04d", number);
		String taskNo = "R" + date + numFormat;
		inspectionTasks.setTaskNo(taskNo);
		return R.status(inspectionTasksService.saveOrUpdate(inspectionTasks));
	}


	/**
	 * 删除 巡检任务
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inspectionTasksService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 启动 巡检任务
	 */
	@PostMapping("/action")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R auditing(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve("1",ids, "");
	}

	/**
	 * 停止 巡检任务
	 */
	@PostMapping("/stop")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R stop(@ApiParam(value = "主键集合", required = true) @RequestParam String ids, @RequestParam String reason) {
		return this.approve("2",ids, reason);
	}

	/**
	 * 启动OR停止 巡检任务
	 */
	public R approve(String status, String ids, String reason) {
		List<InspectionTasks> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			InspectionTasks inspectionTasks = new InspectionTasks();
			inspectionTasks.setId(Long.parseLong(id));
			inspectionTasks.setTaskStatus(Long.parseLong(status));
			inspectionTasks.setCancelReason(reason);
			list.add(inspectionTasks);
		}
		return R.status(inspectionTasksService.updateBatchById(list));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		entity.remove("daf-auth");
		InspectionTasks vo = DataUtils.mapToEntity(entity, InspectionTasks::new);
		List<InspectionTasksExcel> list = inspectionTasksService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("巡检任务数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), InspectionTasksExcel.class).sheet("巡检任务").doWrite(list);
	}

	@GetMapping("/getListByToolsCodeId")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "通过工器具编码获取巡检任务", notes = "通过工器具编码获取巡检任务")
	public R<List<InspectionTasks>> getListByToolsCodeId(String toolsCodeId) {
		List<InspectionTasks> pages = inspectionTasksService.getListByToolsCodeId(toolsCodeId);
		return R.data(pages);
	}


}
