/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.entity.InventoryDocument;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.leger.entity.InspectionStandards;
import org.energy.modules.leger.vo.InspectionStandardsVO;
import org.energy.modules.leger.service.IInspectionStandardsService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 检验标准一览 控制器
 *
 * @author Daf
 * @since 2024-07-09
 */
@RestController
@AllArgsConstructor
@RequestMapping("/inspectionstandards")
@Api(value = "检验标准一览", tags = "检验标准一览接口")
public class InspectionStandardsController extends DafController {

	private IInspectionStandardsService inspectionStandardsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inspectionStandards")
	public R<InspectionStandards> detail(InspectionStandards inspectionStandards) {
		InspectionStandards detail = inspectionStandardsService.getOne(Condition.getQueryWrapper(inspectionStandards));
		return R.data(detail);
	}

	/**
	 * 分页 检验标准一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inspectionStandards")
	public R<IPage<InspectionStandards>> list(InspectionStandards inspectionStandards, Query query) {
		IPage<InspectionStandards> pages = inspectionStandardsService.page(Condition.getPage(query), Condition.getQueryWrapper(inspectionStandards));
		return R.data(pages);
	}

	/**
	 * 自定义分页 检验标准一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inspectionStandards")
	public R<IPage<InspectionStandardsVO>> page(InspectionStandardsVO inspectionStandards, Query query) {
		IPage<InspectionStandardsVO> pages = inspectionStandardsService.selectInspectionStandardsPage(Condition.getPage(query), inspectionStandards);
		return R.data(pages);
	}

	/**
	 * 新增 检验标准一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inspectionStandards")
	public R save(@Valid @RequestBody InspectionStandards inspectionStandards) {
		return R.status(inspectionStandardsService.save(inspectionStandards));
	}

	/**
	 * 修改 检验标准一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inspectionStandards")
	public R update(@Valid @RequestBody InspectionStandards inspectionStandards) {
		return R.status(inspectionStandardsService.updateById(inspectionStandards));
	}

	/**
	 * 新增或修改 检验标准一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inspectionStandards")
	public R submit(@Valid @RequestBody InspectionStandards inspectionStandards) {
		return R.status(inspectionStandardsService.saveOrUpdate(inspectionStandards));
	}


	/**
	 * 删除 检验标准一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inspectionStandardsService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 检验标准一览
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入inspectionStandards")
	public R<List<InspectionStandards>> getList(InspectionStandards inspectionStandards) {
		List<InspectionStandards> list = inspectionStandardsService.list(Condition.getQueryWrapper(inspectionStandards));
		return R.data(list);
	}

	/**
	 * 删除 检验标准一览
	 */
	@GetMapping("/del")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "逻辑删除", notes = "传入toolscodeid")
	public R del(@ApiParam(value = "主键集合", required = true) @RequestParam Long toolsCodeId) {
		return R.status(inspectionStandardsService.delInspectionStandards(toolsCodeId));
	}

}
