/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.entity.TechParameters;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.leger.entity.InventoryDocument;
import org.energy.modules.leger.vo.InventoryDocumentVO;
import org.energy.modules.leger.service.IInventoryDocumentService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 文档清册一览 控制器
 *
 * @author Daf
 * @since 2024-07-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/inventorydocument")
@Api(value = "文档清册一览", tags = "文档清册一览接口")
public class InventoryDocumentController extends DafController {

	private IInventoryDocumentService inventoryDocumentService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入inventoryDocument")
	public R<InventoryDocument> detail(InventoryDocument inventoryDocument) {
		InventoryDocument detail = inventoryDocumentService.getOne(Condition.getQueryWrapper(inventoryDocument));
		return R.data(detail);
	}

	/**
	 * 分页 文档清册一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入inventoryDocument")
	public R<IPage<InventoryDocument>> list(InventoryDocument inventoryDocument, Query query) {
		IPage<InventoryDocument> pages = inventoryDocumentService.page(Condition.getPage(query), Condition.getQueryWrapper(inventoryDocument));
		return R.data(pages);
	}

	/**
	 * 自定义分页 文档清册一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入inventoryDocument")
	public R<IPage<InventoryDocumentVO>> page(InventoryDocumentVO inventoryDocument, Query query) {
		IPage<InventoryDocumentVO> pages = inventoryDocumentService.selectInventoryDocumentPage(Condition.getPage(query), inventoryDocument);
		return R.data(pages);
	}

	/**
	 * 新增 文档清册一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入inventoryDocument")
	public R save(@Valid @RequestBody InventoryDocument inventoryDocument) {
		return R.status(inventoryDocumentService.save(inventoryDocument));
	}

	/**
	 * 修改 文档清册一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入inventoryDocument")
	public R update(@Valid @RequestBody InventoryDocument inventoryDocument) {
		return R.status(inventoryDocumentService.updateById(inventoryDocument));
	}

	/**
	 * 新增或修改 文档清册一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入inventoryDocument")
	public R submit(@Valid @RequestBody InventoryDocument inventoryDocument) {
		return R.status(inventoryDocumentService.saveOrUpdate(inventoryDocument));
	}


	/**
	 * 删除 文档清册一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(inventoryDocumentService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 列表 技术参数一览
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入inventoryDocument")
	public R<List<InventoryDocument>> getList(InventoryDocument inventoryDocument) {
		List<InventoryDocument> list = inventoryDocumentService.list(Condition.getQueryWrapper(inventoryDocument));
		return R.data(list);
	}

	/**
	 * 删除 技术参数一览
	 */
	@GetMapping("/del")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "逻辑删除", notes = "传入eqLedgerId")
	public R del(@ApiParam(value = "主键集合", required = true) @RequestParam Long eqLedgerId) {
		return R.status(inventoryDocumentService.delInventoryDocument(eqLedgerId));
	}
}
