/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.leger.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.entity.EquipmentLedger;
import org.energy.modules.leger.entity.TechParameters;
import org.energy.modules.leger.excel.EquipmentLedgerExcel;
import org.energy.modules.leger.excel.ToolInventoryRecordExcel;
import org.energy.modules.leger.service.*;
import org.energy.modules.leger.vo.EquipmentLedgerVO;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.leger.entity.ToolInventoryRecord;
import org.energy.modules.leger.vo.ToolInventoryRecordVO;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.ArrayList;
import java.util.List;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.util.Map;

/**
 * 工器具编码一览 控制器
 *
 * @author Daf
 * @since 2024-07-09
 */
@RestController
@AllArgsConstructor
@RequestMapping("/leger/toolinventoryrecord")
@Api(value = "工器具编码一览", tags = "工器具编码一览接口")
public class ToolInventoryRecordController extends DafController {

	private IToolInventoryRecordService toolInventoryRecordService;
	private IInventoryDocumentService inventoryDocumentService;
	private ITechParametersService techParametersService;
	private IInspectionStandardsService inspectionStandardsService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入toolInventoryRecord")
	public R<ToolInventoryRecord> detail(ToolInventoryRecord toolInventoryRecord) {
		ToolInventoryRecord detail = toolInventoryRecordService.getOne(Condition.getQueryWrapper(toolInventoryRecord));
		return R.data(detail);
	}

	/**
	 * 分页 工器具编码一览
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入toolInventoryRecord")
	public R<IPage<ToolInventoryRecord>> list(ToolInventoryRecord toolInventoryRecord, Query query) {
		QueryWrapper<ToolInventoryRecord> qw = new QueryWrapper<>();
		qw.orderByAsc("tools_code_id");
		if (StringUtil.isNotEmpty(toolInventoryRecord.getToolsCodeId())) {
			qw.lambda().like(ToolInventoryRecord::getToolsCodeId, toolInventoryRecord.getToolsCodeId());
		}
		if (StringUtil.isNotEmpty(toolInventoryRecord.getToolName())) {
			qw.lambda().like(ToolInventoryRecord::getToolName, toolInventoryRecord.getToolName());
		}
		if (StringUtil.isNotEmpty(toolInventoryRecord.getToolCategory())) {
			qw.lambda().like(ToolInventoryRecord::getToolCategory, toolInventoryRecord.getToolCategory());
		}
		if (StringUtil.isNotEmpty(toolInventoryRecord.getToolStatus())) {
			qw.lambda().like(ToolInventoryRecord::getToolStatus, toolInventoryRecord.getToolStatus());
		}
		if (null != toolInventoryRecord.getIsInspectionPeriod()) {
			qw.lambda().eq(ToolInventoryRecord::getIsInspectionPeriod, toolInventoryRecord.getIsInspectionPeriod());
		}
		if (null != toolInventoryRecord.getStations()) {
			qw.lambda().eq(ToolInventoryRecord::getStations, toolInventoryRecord.getStations());
		}

		IPage<ToolInventoryRecord> pages = toolInventoryRecordService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 工器具编码一览
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入toolInventoryRecord")
	public R<IPage<ToolInventoryRecordVO>> page(ToolInventoryRecordVO toolInventoryRecord, Query query) {
		IPage<ToolInventoryRecordVO> pages = toolInventoryRecordService.selectToolInventoryRecordPage(Condition.getPage(query), toolInventoryRecord);
		return R.data(pages);
	}

	/**
	 * 新增 工器具编码一览
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入toolInventoryRecord")
	public R save(@Valid @RequestBody ToolInventoryRecord toolInventoryRecord) {
		return R.status(toolInventoryRecordService.save(toolInventoryRecord));
	}

	/**
	 * 修改 工器具编码一览
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入toolInventoryRecord")
	public R update(@Valid @RequestBody ToolInventoryRecord toolInventoryRecord) {
		return R.status(toolInventoryRecordService.updateById(toolInventoryRecord));
	}

	/**
	 * 新增或修改 工器具编码一览
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入toolInventoryRecord")
	public R submit(@Valid @RequestBody ToolInventoryRecord toolInventoryRecord) {
		return R.status(toolInventoryRecordService.saveOrUpdate(toolInventoryRecord));
	}


	/**
	 * 删除 工器具编码一览
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		for (String id : ids.split(",")) {
			inventoryDocumentService.delInventoryDocument(Long.parseLong(id));
			techParametersService.delTechParameters(Long.parseLong(id));
			inspectionStandardsService.delInspectionStandards(Long.parseLong(id));
		}
		return R.status(toolInventoryRecordService.deleteLogic(Func.toLongList(ids)));
	}
	/**
	 * 审核 工器具台账编码一览
	 */
	@PostMapping("/auditing")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R auditing(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(2,ids);
	}

	/**
	 * 驳回 工器具台账编码一览
	 */
	@PostMapping("/reject")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R reject(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(3,ids);
	}

	/**
	 * 驳回OR审核 工器具台账编码一览
	 */
	public R approve(Integer status, String ids) {
		List<ToolInventoryRecord> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			ToolInventoryRecord toolInventoryRecord = toolInventoryRecordService.getById(Long.parseLong(id));
			toolInventoryRecord.setCheckStatus(status);
			list.add(toolInventoryRecord);
		}
		return R.status(toolInventoryRecordService.updateBatchById(list));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		ToolInventoryRecordVO vo = DataUtils.mapToEntity(entity, ToolInventoryRecordVO::new);
		List<ToolInventoryRecordExcel> list = toolInventoryRecordService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("工器具台账数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), ToolInventoryRecordExcel.class).sheet("工器具台账").doWrite(list);
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getToolsCodeIdList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "获取工器具编码", notes = "获取工器具编码")
	public R<List<ToolInventoryRecord>> getToolsCodeIdList() {
		List<ToolInventoryRecord> kksList = toolInventoryRecordService.getToolsCodeIdList();
		return R.data(kksList);
	}

	/**
	 * 获取工器具明细
	 */
	@GetMapping("/getDetailList")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取工器具信息", notes = "获取工器具信息")
	public R<ToolInventoryRecord> getDetailList(String toolsCodeId) {
		ToolInventoryRecord DetailList = toolInventoryRecordService.getDetailList("'" + toolsCodeId + "'");
		return R.data(DetailList);
	}

	/**
	 * 获取对象编号
	 */
	@GetMapping("/getToolsCodeId")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取工器具信息", notes = "获取工器具信息")
	public R<ToolInventoryRecord> getToolsCodeId(String toolsCodeId) {
		ToolInventoryRecord DetailList = toolInventoryRecordService.getToolsCodeId("'" + toolsCodeId + "'");
		return R.data(DetailList);
	}

}
