/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.master.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.master.entity.EquipmentInspection;
import org.energy.modules.master.vo.EquipmentInspectionVO;
import org.energy.modules.master.service.IEquipmentInspectionService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 工器具检查 控制器
 *
 * @author Daf
 * @since 2025-01-09
 */
@RestController
@AllArgsConstructor
@RequestMapping("/master/equipmentinspection")
@Api(value = "工器具检查", tags = "工器具检查接口")
public class EquipmentInspectionController extends DafController {

	private IEquipmentInspectionService equipmentInspectionService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入equipmentInspection")
	public R<EquipmentInspection> detail(EquipmentInspection equipmentInspection) {
		EquipmentInspection detail = equipmentInspectionService.selectDetail(equipmentInspection.getId());
		return R.data(detail);
	}

	/**
	 * 检查内容详情
	 */
	@GetMapping("/detail2")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "详情", notes = "传入equipmentInspection")
	public R<List<EquipmentInspectionVO>> detail2(EquipmentInspection equipmentInspection) {
		List<EquipmentInspectionVO> detail2 = equipmentInspectionService.selectDetail2(equipmentInspection.getId());
		return R.data(detail2);
	}

	/**
	 * 分页 工器具检查
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入equipmentInspection")
	public R<IPage<EquipmentInspection>> list(EquipmentInspection equipmentInspection, Query query) {
		IPage<EquipmentInspection> pages = equipmentInspectionService.page(Condition.getPage(query), Condition.getQueryWrapper(equipmentInspection));
		return R.data(pages);
	}

	/**
	 * 自定义分页 工器具检查
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入equipmentInspection")
	public R<IPage<EquipmentInspectionVO>> page(EquipmentInspectionVO equipmentInspection, Query query) {
		IPage<EquipmentInspectionVO> pages = equipmentInspectionService.selectEquipmentInspectionPage(Condition.getPage(query), equipmentInspection);
		return R.data(pages);
	}

	/**
	 * 新增 工器具检查
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入equipmentInspection")
	public R save(@Valid @RequestBody EquipmentInspection equipmentInspection) {
		return R.status(equipmentInspectionService.save(equipmentInspection));
	}

	/**
	 * 修改 工器具检查
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入equipmentInspection")
	public R update(@Valid @RequestBody EquipmentInspection equipmentInspection) {
		return R.status(equipmentInspectionService.updateById(equipmentInspection));
	}

	/**
	 * 新增或修改 工器具检查
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入equipmentInspection")
	public R submit(@Valid @RequestBody EquipmentInspection equipmentInspection) {
		equipmentInspection.setInspectionStatus(1);

		return R.status(equipmentInspectionService.saveOrUpdate(equipmentInspection));
	}


	/**
	 * 删除 工器具检查
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(equipmentInspectionService.deleteLogic(Func.toLongList(ids)));
	}


}
