/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.org.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.service.IInspectionStandardsService;
import org.energy.modules.leger.service.IInventoryDocumentService;
import org.energy.modules.leger.service.ITechParametersService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.org.entity.PositionInfo;
import org.energy.modules.org.vo.PositionInfoVO;
import org.energy.modules.org.service.IPositionInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 岗位信息 控制器
 *
 * @author Daf
 * @since 2024-12-17
 */
@RestController
@AllArgsConstructor
@RequestMapping("/org/positioninfo")
@Api(value = "岗位信息", tags = "岗位信息接口")
public class PositionInfoController extends DafController {

	private IPositionInfoService positionInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入positionInfo")
	public R<PositionInfo> detail(PositionInfo positionInfo) {
		PositionInfoVO detail = positionInfoService.selectDetail(positionInfo.getId());
		return R.data(detail);
	}

	/**
	 * 分页 岗位信息
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入positionInfo")
	public R<IPage<PositionInfo>> list(PositionInfo positionInfo, Query query) {
		IPage<PositionInfo> pages = positionInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(positionInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 岗位信息
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入positionInfo")
	public R<IPage<PositionInfoVO>> page(PositionInfoVO positionInfo, Query query) {
		IPage<PositionInfoVO> pages = positionInfoService.selectPositionInfoPage(Condition.getPage(query), positionInfo);
		return R.data(pages);
	}

	/**
	 * 新增 岗位信息
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入positionInfo")
	public R save(@Valid @RequestBody PositionInfo positionInfo) {
		return R.status(positionInfoService.save(positionInfo));
	}

	/**
	 * 修改 岗位信息
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入positionInfo")
	public R update(@Valid @RequestBody PositionInfo positionInfo) {
		return R.status(positionInfoService.updateById(positionInfo));
	}

	/**
	 * 新增或修改 岗位信息
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入positionInfo")
	public R submit(@Valid @RequestBody PositionInfo positionInfo) {
		return R.status(positionInfoService.saveOrUpdate(positionInfo));
	}


	/**
	 * 删除 岗位信息
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(positionInfoService.deleteLogic(Func.toLongList(ids)));
	}
	/**
	 * 岗位下拉列表信息
	 */
	@GetMapping("/selectInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "下拉", notes = "")
	public List<PositionInfoVO> positionSelectInfo(String stationCode) {
		List<PositionInfoVO>  positionInfoList= positionInfoService.positionInfoData(stationCode);
		return positionInfoList;
	}

}
