/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.smart.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xkcoding.http.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import org.energy.modules.leger.entity.InventoryDocument;
import org.energy.modules.smart.entity.OperationTicket;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.smart.entity.OperationItem;
import org.energy.modules.smart.vo.OperationItemVO;
import org.energy.modules.smart.service.IOperationItemService;
import com.dayu.daf.core.boot.ctrl.DafController;

import java.util.List;

/**
 * 操作项目表 控制器
 *
 * @author Daf
 * @since 2024-07-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("/smart/operationitem")
@Api(value = "操作项目表", tags = "操作项目表接口")
public class OperationItemController extends DafController {

	private IOperationItemService operationItemService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入operationItem")
	public R<OperationItem> detail(OperationItem operationItem) {
		OperationItem detail = operationItemService.getOne(Condition.getQueryWrapper(operationItem));
		return R.data(detail);
	}

	/**
	 * 分页 操作项目表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入operationItem")
	public R<IPage<OperationItem>> list(OperationItem operationItem, Query query) {
		IPage<OperationItem> pages = operationItemService.page(Condition.getPage(query), Condition.getQueryWrapper(operationItem));
		return R.data(pages);
	}

	/**
	 * 自定义分页 操作项目表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入operationItem")
	public R<IPage<OperationItemVO>> page(OperationItemVO operationItem, Query query) {
		IPage<OperationItemVO> pages = operationItemService.selectOperationItemPage(Condition.getPage(query), operationItem);
		return R.data(pages);
	}

	/**
	 * 新增 操作项目表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入operationItem")
	public R save(@Valid @RequestBody OperationItem operationItem) {
		return R.status(operationItemService.save(operationItem));
	}

	/**
	 * 修改 操作项目表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入operationItem")
	public R update(@Valid @RequestBody OperationItem operationItem) {
		return R.status(operationItemService.updateById(operationItem));
	}

	/**
	 * 新增或修改 操作项目表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入operationItem")
	public R submit(@Valid @RequestBody OperationItem operationItem) {
		String perationItemNo = operationItem.getOperationTicketNo()+"XM";
		String maxOperationItemNo =
			operationItemService.getMaxOperationItemNo("'"+operationItem.getOperationTicketNo()+"'");
		int number;
		if (StringUtil.isNotEmpty(maxOperationItemNo)){
			number = Integer.parseInt(maxOperationItemNo.substring(maxOperationItemNo.length()-4));
			number++;
		}else{
			number = 1;
		}
		String numFormat = String.format("%04d", number);
		operationItem.setOperationItemNo(perationItemNo+numFormat);
		return R.status(operationItemService.saveOrUpdate(operationItem));
	}


	/**
	 * 删除 操作项目表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(operationItemService.deleteLogic(Func.toLongList(ids)));
	}
	/**
	 * 列表 操作项目
	 */
	@GetMapping("/getList")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "列表", notes = "传入OperationItem")
	public R<List<OperationItem>> getList(OperationItem operationItem) {
		List<OperationItem> list = operationItemService.list(Condition.getQueryWrapper(operationItem));
		return R.data(list);
	}

}
