/**
 * Copyright (c) 2018-2028, Chill Zhuang 庄骞 (smallchill@163.com).
 * <p>
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE 3.0;
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.gnu.org/licenses/lgpl.html
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.energy.modules.spares.controller;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dayu.daf.core.log.annotation.ApiLog;
import com.dayu.daf.core.tool.constant.DafConstant;
import io.micrometer.core.instrument.util.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.dayu.daf.core.mp.support.Condition;
import com.dayu.daf.core.mp.support.Query;
import com.dayu.daf.core.tool.api.R;
import com.dayu.daf.core.tool.utils.Func;
import lombok.SneakyThrows;
import org.apache.commons.codec.Charsets;
import org.energy.modules.spares.excel.SupplierInfoExcel;
import org.energy.modules.system.util.DataUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.energy.modules.spares.entity.SupplierInfo;
import org.energy.modules.spares.vo.SupplierInfoVO;
import org.energy.modules.spares.service.ISupplierInfoService;
import com.dayu.daf.core.boot.ctrl.DafController;
import springfox.documentation.annotations.ApiIgnore;

import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * spt_supplier_info 控制器
 *
 * @author Daf
 * @since 2024-07-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("/supplierinfo")
@Api(value = "spt_supplier_info", tags = "spt_supplier_info接口")
public class SupplierInfoController extends DafController {

	private ISupplierInfoService supplierInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入supplierInfo")
	public R<SupplierInfo> detail(SupplierInfo supplierInfo) {
		SupplierInfo detail = supplierInfoService.getOne(Condition.getQueryWrapper(supplierInfo));
		return R.data(detail);
	}

	/**
	 * 分页 spt_supplier_info
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入supplierInfo")
	public R<IPage<SupplierInfo>> list(SupplierInfo supplierInfo, Query query) {
		QueryWrapper<SupplierInfo> qw = new QueryWrapper<>();
		if (StringUtils.isNotEmpty(supplierInfo.getCreditCode())) {
			qw.lambda().like(SupplierInfo::getCreditCode, supplierInfo.getCreditCode());
		}
		if (StringUtils.isNotEmpty(supplierInfo.getSupplierName())) {
			qw.lambda().like(SupplierInfo::getSupplierName, supplierInfo.getSupplierName());
		}
		qw.lambda().eq(SupplierInfo::getIsDeleted, DafConstant.DB_NOT_DELETED);
		qw.lambda().orderByDesc(SupplierInfo::getUpdateTime);
		IPage<SupplierInfo> pages = supplierInfoService.page(Condition.getPage(query), qw);
		return R.data(pages);
	}

	/**
	 * 自定义分页 spt_supplier_info
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入supplierInfo")
	public R<IPage<SupplierInfoVO>> page(SupplierInfoVO supplierInfo, Query query) {
		IPage<SupplierInfoVO> pages = supplierInfoService.selectSupplierInfoPage(Condition.getPage(query), supplierInfo);
		return R.data(pages);
	}

	/**
	 * 新增 spt_supplier_info
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入supplierInfo")
	public R save(@Valid @RequestBody SupplierInfo supplierInfo) {
		return R.status(supplierInfoService.save(supplierInfo));
	}

	/**
	 * 修改 spt_supplier_info
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入supplierInfo")
	public R update(@Valid @RequestBody SupplierInfo supplierInfo) {
		return R.status(supplierInfoService.updateById(supplierInfo));
	}

	/**
	 * 新增或修改 spt_supplier_info
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入supplierInfo")
	public R submit(@Valid @RequestBody SupplierInfo supplierInfo) {
		return R.status(supplierInfoService.saveOrUpdate(supplierInfo));
	}


	/**
	 * 删除 spt_supplier_info
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(supplierInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 审核
	 */
	@PostMapping("/auditing")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R auditing(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(2,ids);
	}

	/**
	 * 驳回
	 */
	@PostMapping("/reject")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "更新", notes = "传入ids")
	public R reject(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return this.approve(3,ids);
	}

	/**
	 * 驳回OR审核
	 */
	public R approve(Integer status, String ids) {
		List<SupplierInfo> list = new ArrayList<>();
		for (String id : ids.split(",")) {
			SupplierInfo supplierInfo = new SupplierInfo();
			supplierInfo.setId(Long.parseLong(id));
			supplierInfo.setApprovalStatus(status);
			list.add(supplierInfo);
		}
		return R.status(supplierInfoService.updateBatchById(list));
	}

	/**
	 * 导出
	 */
	@SneakyThrows
	@GetMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出", notes = "传入")
	@ApiLog
	public void exportUser(@ApiIgnore @RequestParam Map<String, Object> entity, HttpServletResponse response) {
		entity.remove("daf-auth");
		SupplierInfoVO vo = DataUtils.mapToEntity(entity, SupplierInfoVO::new);
		List<SupplierInfoExcel> list = supplierInfoService.export(vo);
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding(Charsets.UTF_8.name());
		String fileName = URLEncoder.encode("供应商信息管理数据导出", Charsets.UTF_8.name());
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		EasyExcel.write(response.getOutputStream(), SupplierInfoExcel.class).sheet("供应商信息管理").doWrite(list);
	}

	/**
	 * 获取供应商
	 */
	@GetMapping("/getNoList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "获取编号", notes = "获取编号")
	public R<List<SupplierInfo>> getNoList() {
		List<SupplierInfo> noList = supplierInfoService.getNoList();
		return R.data(noList);
	}

	/**
	 * 获取供应商信息
	 */
	@GetMapping("/getDetail")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "获取供应商信息", notes = "获取供应商信息")
	public R<SupplierInfo> getDetail(String creditCode) {
		SupplierInfo detail = supplierInfoService.getDetail(creditCode);
		return R.data(detail);
	}


}
