package org.energy.modules.system.util;

import org.apache.commons.csv.CSVFormat;
import org.apache.commons.csv.CSVParser;
import org.apache.commons.csv.CSVRecord;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class CsvFileUtils {

	private static final Logger logger = LoggerFactory.getLogger(CsvFileUtils.class);

	public static String isCsvFormatValid(MultipartFile file, BigDecimal pvInsatll) {
		StringBuilder sb = new StringBuilder();
		try (InputStream inputStream = file.getInputStream();
			 BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream, StandardCharsets.UTF_8));
			 CSVParser parser = new CSVParser(reader, CSVFormat.DEFAULT.
				 withFirstRecordAsHeader().withIgnoreHeaderCase().withTrim())) {
			// 获取标题
			List<String> headers = parser.getHeaderNames();
			int numberOfColumns = headers.size();
			int index = 1;
			for (CSVRecord record : parser) {
				// 检查列数是否一致
				if (record.size() != numberOfColumns) {
					sb.append("上传失败,文件内容为空或模板不对");
					break;
				}
				checkCsvField(record, sb, index, pvInsatll);
				break;
			}
		} catch (IOException e) {
			sb.append("上传失败,文件内容读取失败");
		}
		return sb.toString();
	}

	public static void checkCsvField(CSVRecord record, StringBuilder sb, int index, BigDecimal pvInsatll) {
		// 正则表达式
		String dataPattern = "^?[0-9]{0,4}+\\.?[0-9]{0,2}$";
		Pattern pattern = Pattern.compile(dataPattern);
		for (int i = 1; i <= 24; i++) {
			String fieldValue = record.get(i - 1);
			if (StringUtils.isEmpty(fieldValue)) {
				sb.append("第").append(index).append("行上传失败,时间段").append(i).append("不可为空").append("</br>");
			} else {
				Matcher matcher = pattern.matcher(fieldValue);
				if (!matcher.matches()) {
					sb.append("第").append(index).append("行上传失败,时间段").append(i).append("请填写整数四位以内,小数两位数字").append("</br>");
				} else if (pvInsatll != null && new BigDecimal(fieldValue).compareTo(pvInsatll) > 0) {
					sb.append("第").append(index).append("行上传失败,时间段").append(i).append("不能大于光伏装机(").append(pvInsatll).append(")").append("</br>");
				}
			}
		}
	}

	public static void download(HttpServletResponse response, String templateName) throws Exception {
		InputStream in = null;
		OutputStream out = null;
		try {
			InputStream inputStream = Thread.currentThread().getContextClassLoader().getResourceAsStream("csv/" + templateName);
			//强制下载不打开
			response.setContentType("application/force-download");
			out = response.getOutputStream();
			//使用URLEncoder来防止文件名乱码或者读取错误
			response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(templateName, "UTF-8"));
			int b = 0;
			byte[] buffer = new byte[1000000];
			while (b != -1) {
				b = inputStream.read(buffer);
				if (b != -1) {
					out.write(buffer, 0, b);
				}
			}
			int bytes = 0;
			byte[] bufferOut = new byte[1024];
			while ((bytes = in.read(bufferOut)) != -1) {
				out.write(bufferOut, 0, bytes);
			}
			out.close();
			in.close();
		} finally {
			if (in != null) {
				try {
					in.close();
				} catch (IOException e) {
					logger.error("文件流关闭失败", e);
				}
			}

			if (null != out) {
				out.close();
			}

		}

	}
}
